@@ -2,12 +2,18 @@
 
 set -e
 
+GOARCH=$(go env GOARCH)
+
 run_integration_test() {
   ES_VERSION=$1
   docker pull docker.elastic.co/elasticsearch/elasticsearch:${ES_VERSION}
   CID=$(docker run --rm -d -p 9200:9200 -e "http.host=0.0.0.0" -e "transport.host=127.0.0.1" -e "xpack.security.enabled=false" -e "xpack.monitoring.enabled=false" docker.elastic.co/elasticsearch/elasticsearch:${ES_VERSION})
-  STORAGE=elasticsearch make storage-integration-test
-  make index-cleaner-integration-test
+  if [ "$ES_OTEL_INTEGRATION_TEST" == true ]; then
+    make es-otel-exporter-integration-test
+  else
+    STORAGE=elasticsearch make storage-integration-test
+    make index-cleaner-integration-test
+  fi
   docker kill $CID
 }
 
@@ -15,6 +21,11 @@ run_integration_test "5.6.16"
 run_integration_test "6.8.2"
 run_integration_test "7.3.0"
 
+if [ "$ES_OTEL_INTEGRATION_TEST" == true ]; then
+  echo "OpenTelemetry ES exporter test finished, skipping ES script tests and token propagation"
+  exit 0
+fi
+
 echo "Executing token propatagion test"
 
 # Mock UI, needed only for build query service.
@@ -22,7 +33,7 @@ make build-crossdock-ui-placeholder
 GOOS=linux make build-query
 
 make test-compile-es-scripts
-SPAN_STORAGE_TYPE=elasticsearch ./cmd/query/query-linux --es.server-urls=http://127.0.0.1:9200 --es.tls=false --es.version=7 --query.bearer-token-propagation=true &
+SPAN_STORAGE_TYPE=elasticsearch ./cmd/query/query-linux-$GOARCH --es.server-urls=http://127.0.0.1:9200 --es.tls=false --es.version=7 --query.bearer-token-propagation=true &
 PID=$(echo $!)
 make token-propagation-integration-test
 kill -9 ${PID}
